@@ -6,6 +6,7 @@
 use std::collections::BTreeMap;
 use std::fmt;
 
+use itertools::Itertools;
 use k8s_openapi::apimachinery;
 use k8s_openapi::ByteString;
 use kube::api;
@@ -39,6 +40,7 @@ impl Kubectl {
         })
     }
 
+    #[must_use]
     pub fn manager(self, manager: &str) -> Self {
         Self {
             manager: manager.to_string(),
@@ -147,15 +149,26 @@ impl Kubectl {
         Ok(object)
     }
 
-    pub async fn patch<K>(&self, object: K, api: kube::Api<K>) -> kube::Result<K>
-    where
-        K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
-        <K as kube::Resource>::DynamicType: Default,
-    {
-        let name = object.name();
-        let patch = api::Patch::Apply(&object);
-        api.patch(&name, &self.patch_with_manager(&self.manager), &patch)
-            .await
+    pub async fn list_pods_from_deployment<'a>(
+        &self,
+        deployment: &str,
+        namespace: impl Into<Option<&'a str>>,
+    ) -> kube::Result<Vec<corev1::Pod>> {
+        let namespace = namespace.into();
+        let deployment = self.get_deployment(deployment, namespace).await?;
+        let label_selector = deployment
+            .spec
+            .unwrap_or_default()
+            .selector
+            .match_labels
+            .unwrap_or_default()
+            .into_iter()
+            // Drop this `key = key` artifact after 1.58 becomes stable
+            .map(|(key, value)| format!("{key}={value}", key = key, value = value))
+            .join(",");
+
+        let lp = self.list_params().labels(&label_selector);
+        self.pods(namespace).list(&lp).await.map(|pods| pods.items)
     }
 }
 
