@@ -31,6 +31,17 @@ impl super::Kubectl {
         api::PatchParams::apply(manager)
     }
 
+    pub async fn patch<K>(&self, object: K, api: kube::Api<K>) -> kube::Result<K>
+    where
+        K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
+        <K as kube::Resource>::DynamicType: Default,
+    {
+        let name = object.name();
+        let patch = api::Patch::Apply(&object);
+        api.patch(&name, &self.patch_with_manager(&self.manager), &patch)
+            .await
+    }
+
     pub fn api<T>(&self) -> api::Api<T>
     where
         T: kube::Resource,
@@ -115,6 +126,14 @@ impl super::Kubectl {
         }
     }
 
+    pub async fn get_deployment<'a>(
+        &self,
+        name: &str,
+        namespace: impl Into<Option<&'a str>>,
+    ) -> kube::Result<appsv1::Deployment> {
+        self.deployments(namespace).get(name).await
+    }
+
     pub async fn get_secret(&self, name: &str) -> kube::Result<corev1::Secret> {
         self.secrets(None).get(name).await
     }
